==> cxf-testutils-2.0.6.16-fuse-sources.jar: org/apache/type_test/xml/TestAnonymousType.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.AnonymousType;


/**
 * <p>Java class for testAnonymousType element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testAnonymousType">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}AnonymousType"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}AnonymousType"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testAnonymousType")
public class TestAnonymousType {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected AnonymousType x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected AnonymousType y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link AnonymousType }
     *     
     */
    public AnonymousType getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnonymousType }
     *     
     */
    public void setX(AnonymousType value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link AnonymousType }
     *     
     */
    public AnonymousType getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnonymousType }
     *     
     */
    public void setY(AnonymousType value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.20-fuse-sources.jar: org/apache/type_test/xml/TestAnonymousType.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.AnonymousType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}AnonymousType"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}AnonymousType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testAnonymousType")
public class TestAnonymousType {

    @XmlElement(required = true)
    protected AnonymousType x;
    @XmlElement(required = true)
    protected AnonymousType y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link AnonymousType }
     *     
     */
    public AnonymousType getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnonymousType }
     *     
     */
    public void setX(AnonymousType value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link AnonymousType }
     *     
     */
    public AnonymousType getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnonymousType }
     *     
     */
    public void setY(AnonymousType value) {
        this.y = value;
    }

}
